Class: annotation - LinkML Model

# Class: annotation

a tag/value pair with the semantics of OWL Annotation

URI: linkml:Annotation

## Parents

- is_a: Extension - a tag/value pair used to add non-model information to an entry

## Uses Mixin

- mixin: Annotatable - mixin for classes that support annotations

## Referenced by Class

- Annotatable annotations 0..* Annotation

## Attributes

### Own

- annotations 0..*
  - Description: a collection of tag/text tuples with the semantics of OWL Annotation
  - Range: Annotation

### Inherited from extension:

- extension➞tag 1..1
  - Description: a tag associated with an extension
  - Range: Uriorcurie
- extension➞value 1..1
  - Description: the actual annotation
  - Range: String
- extensions 0..*
  - Description: a tag/text tuple attached to an arbitrary element
  - Range: Extension